==> kvpnc_0.8.5.1.orig.tar.gz: kvpnc-0.8.5.1/src/profileuseroptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "profileuseroptions.h"

ProfileUserOptions::ProfileUserOptions(QWidget *parent)
		: ProfileUserOptionsBase(parent)
{}


ProfileUserOptions::~ProfileUserOptions()
{}

==> kvpnc_0.9.0.orig.tar.gz: kvpnc-0.9.0.orig/src/profileuseroptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Christoph Thielecke                             *
 *   crissi99@gmx.de                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "profileuseroptions.h"

#include <qcheckbox.h>
#include <klineedit.h>

ProfileUserOptions::ProfileUserOptions(QWidget *parent)
		: ProfileUserOptionsBase(parent)
{}


ProfileUserOptions::~ProfileUserOptions()
{}

void ProfileUserOptions::domainNameToggled(bool)
{
	if ( NtDomainNameCheckbox->isChecked() )
		NtDomainNameLineedit->setEnabled( true );
	else
		NtDomainNameLineedit->setEnabled( false );
}
